pub enum TokenScope {
Read,
Write,
}Expand description
CAS token scope.
Variants
Read
Read-only CAS access.
Write
Write access, including the read behavior required by upload clients.
Implementations
Sourceimpl TokenScope
impl TokenScope
Sourcepub const fn allows_read(self) -> bool
pub const fn allows_read(self) -> bool
Returns true when this scope can perform read operations.
Sourcepub const fn allows_write(self) -> bool
pub const fn allows_write(self) -> bool
Returns true when this scope can perform write operations.