pub struct ShardlineHash { /* private fields */ }Expand description
A 32-byte protocol hash.
Implementations
Sourceimpl ShardlineHash
impl ShardlineHash
Sourcepub const fn from_bytes(bytes: [u8; 32]) -> Self
pub const fn from_bytes(bytes: [u8; 32]) -> Self
Creates a hash from raw bytes.
Sourcepub fn parse_hex(value: &str) -> Result<Self, HashParseError>
pub fn parse_hex(value: &str) -> Result<Self, HashParseError>
Parses a hash from canonical lowercase hexadecimal text.
Errors
Returns HashParseError when the string has the wrong length, contains
non-lowercase hexadecimal characters, or cannot be decoded into 32 bytes.
Sourcepub fn hex_string(&self) -> String
pub fn hex_string(&self) -> String
Returns canonical lowercase hexadecimal text.